.. -*- mode: rst -*-

cppyy: Python-C++ bindings interface based on Cling/LLVM
========================================================

cppyy provides fully automatic, dynamic Python-C++ bindings by leveraging
the Cling C++ interpreter and LLVM.
It supports both PyPy (natively), CPython, and C++ language standards
through C++17.

Details and performance are described in
`this paper <http://cern.ch/wlav/Cppyy_LavrijsenDutta_PyHPC16.pdf>`_,
originally presented at PyHPC'16, but since updated with improved performance
numbers.

Full documentation: `cppyy.readthedocs.io <http://cppyy.readthedocs.io/>`_.

Notebook-based tutorial: `Cppyy Tutorial <https://bitbucket.org/wlav/cppyy/src/master/doc/tutorial/CppyyTutorial.ipynb?viewer=nbviewer&fileviewer=notebook-viewer%3Anbviewer>`_.

For Anaconda/miniconda, install cppyy from `conda-forge <https://anaconda.org/conda-forge/cppyy>`_.

----

Change log:
  https://cppyy.readthedocs.io/en/latest/changelog.html

Bug reports/feedback:
  https://bitbucket.org/wlav/cppyy/issues?status=new&status=open
